@@ -1,6 +1,6 @@
 /*
  * debug.c - debug function
- * Copyright (C) 2015 Tetsumune KISO <t2mune@gmail.com>
+ * Copyright (C) 2011-2024 Tetsumune KISO <t2mune@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,7 +48,7 @@ void rec_dbg(int level, char *format, ...)
     int i;
 
     for(i = 0; i < level; i++)
-        strncat(indent, "    ", sizeof(indent));
+        strncat(indent, "    ", sizeof(indent)-1);
 
     va_start(ap, format);
 
