@@ -1,6 +1,6 @@
 /*
  * nield.c - evnent receiver
- * Copyright (C) 2015 Tetsumune KISO <t2mune@gmail.com>
+ * Copyright (C) 2011-2024 Tetsumune KISO <t2mune@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,7 +65,9 @@
 # include <linux/tc_act/tc_csum.h>
 #endif
 #include <linux/tc_act/tc_gact.h>
+#ifdef HAVE_LINUX_TC_ACT_TC_IPT_H
 #include <linux/tc_act/tc_ipt.h>
+#endif
 #include <linux/tc_act/tc_mirred.h>
 #ifdef HAVE_LINUX_TC_ACT_TC_NAT_H
 # include <linux/tc_act/tc_nat.h>
@@ -116,6 +118,7 @@
 #define M_ROUTE   0x0020
 #define M_RULE    0x0040
 #define M_TC      0x0080
+#define M_XFRM    0x0100
 
 /* interface message type flag */
 #define IF_ADD    0x0001
@@ -170,7 +173,7 @@ void sigint_handler(int sig);
 void sigusr1_handler(int sig);
 void sigusr2_handler(int sig);
 int set_rtnetlink_groups(void);
-int open_netlink_socket(unsigned groups);
+int open_netlink_socket(unsigned groups, int proto);
 int send_request(int sock, int type, int family);
 int recv_reply(int sock, int type);
 int recv_events(int sock);
@@ -317,6 +320,7 @@ const char *conv_macvlan_mode(unsigned mode, unsigned char debug);
 /* ifimsg_vxlan.c */
 #if HAVE_DECL_IFLA_VXLAN_UNSPEC
 int parse_ifla_vxlan(char *msg, char **mp, struct rtattr *info, struct iflist_entry *ifle);
+int parse_ifla_vxlan_id(char *msg, char **mp, struct rtattr *vxlan, struct iflist_entry *ifle);
 int parse_ifla_vxlan_link(char *msg, char **mp, struct rtattr *vxlan, struct iflist_entry *ifle);
 int parse_ifla_vxlan_local(char *msg, char **mp, struct rtattr *vxlan, struct iflist_entry *ifle, unsigned short family);
 int parse_ifla_vxlan_port_range(char *msg, char **mp, struct rtattr *vxlan, struct iflist_entry *ifle);
@@ -485,6 +489,7 @@ void debug_tca_options_hfsc(int lev, struct rtattr *tca, const char *name);
 void debug_tca_hfsc_sc(int lev, struct rtattr *hfsc, const char *name);
 
 /* tcmsg_qdisc_cbq.c */
+#if HAVE_DECL_TCA_CBQ_UNSPEC
 int parse_tca_options_cbq(char *msg, char **mp, struct rtattr *tca);
 void debug_tca_options_cbq(int lev, struct rtattr *tca, const char *name);
 void debug_tca_cbq_lssopt(int lev, struct rtattr *cbq, const char *name);
@@ -497,10 +502,13 @@ void debug_tc_cbq_xstats(int lev, struct rtattr *tca, const char *name);
 void conv_tcf_cbq_lss_change(int change, char *change_list, int len);
 void conv_tcf_cbq_lss_flags(int flags, char *flags_list, int len);
 void conv_tc_cbq_ovl_strategy(int strategy, char *strategy_list, int len);
+#endif
 
 /* tcmsg_qdisc_dsmark.c */
+#if HAVE_DECL_TCA_DSMARK_UNSPEC
 int parse_tca_options_dsmark(char *msg, char **mp, struct rtattr *tca);
 void debug_tca_options_dsmark(int lev, struct rtattr *tca, const char *name);
+#endif
 
 /* tcmsg_qdisc_netem.c */
 int parse_tca_options_netem(char *msg, char **mp, struct rtattr *tca);
@@ -730,4 +738,11 @@ void debug_tca_csum_tm(int lev, struct rtattr *csum, const char *name);
 void debug_tca_csum_parms(int lev, struct rtattr *csum, const char *name);
 void conv_tca_csum_update_flags(int flags, char *flags_list, int len, unsigned char debug);
 #endif
+
+#define APPEND_SNPRINTF(RC, P, LEN, ...) do {   \
+    int RC = snprintf(P, LEN, __VA_ARGS__);     \
+    RC = RC < 0 ? 0 : RC >= LEN ? LEN : RC;     \
+    P += RC;                                    \
+    LEN -= RC;                                  \
+} while(0)
 #endif /* _NIELD_ */
