@@ -1,6 +1,6 @@
 /*
  * tcmsg_filter.c - traffic control filter message parser
- * Copyright (C) 2015 Tetsumune KISO <t2mune@gmail.com>
+ * Copyright (C) 2011-2024 Tetsumune KISO <t2mune@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -102,10 +102,12 @@ int parse_tcmsg_filter(struct nlmsghdr *nlh)
             if(parse_tca_options_u32(msg, &mp, tca[TCA_OPTIONS]))
                 return(1);
             return(0);
+#if HAVE_DECL_TCA_RSVP_UNSPEC
         } else if(!strncmp(kind, "rsvp", sizeof(kind))) {
             if(parse_tca_options_rsvp(msg, &mp, tcm, tca[TCA_OPTIONS]))
                 return(1);
             return(0);
+#endif
         } else if(!strncmp(kind, "route", sizeof(kind))) {
             if(parse_tca_options_route(msg, &mp, tca[TCA_OPTIONS]))
                 return(1);
@@ -114,10 +116,12 @@ int parse_tcmsg_filter(struct nlmsghdr *nlh)
             if(parse_tca_options_fw(msg, &mp, tca[TCA_OPTIONS]))
                 return(1);
             return(0);
+#if HAVE_DECL_TCA_TCINDEX_UNSPEC
         } else if(!strncmp(kind, "tcindex", sizeof(kind))) {
             if(parse_tca_options_tcindex(msg, &mp, tca[TCA_OPTIONS]))
                 return(1);
             return(0);
+#endif
 #if HAVE_DECL_TCA_FLOW_UNSPEC
         } else if(!strncmp(kind, "flow", sizeof(kind))) {
             if(parse_tca_options_flow(msg, &mp, tca[TCA_OPTIONS]))
@@ -199,17 +203,17 @@ int parse_tca_mask(char *msg, char **mp, struct rtattr *tca)
 void parse_u32_handle(char *p, int len, unsigned handle)
 {
     if(TC_U32_HTID(handle))
-        p += snprintf(p, len, "%x", TC_U32_HTID(handle)>>20);
+        APPEND_SNPRINTF(rc, p, len, "%x", TC_U32_HTID(handle)>>20);
 
-    p += snprintf(p, len, ":");
+    APPEND_SNPRINTF(rc, p, len, ":");
 
     if(TC_U32_HASH(handle))
-        p += snprintf(p, len, "%x", TC_U32_HASH(handle));
+        APPEND_SNPRINTF(rc, p, len, "%x", TC_U32_HASH(handle));
 
-    p += snprintf(p, len, ":");
+    APPEND_SNPRINTF(rc, p, len, ":");
 
     if(TC_U32_NODE(handle))
-        p += snprintf(p, len, "%x", TC_U32_NODE(handle));
+        APPEND_SNPRINTF(rc, p, len, "%x", TC_U32_NODE(handle));
 }
 
 /*
@@ -1073,7 +1077,9 @@ const char *conv_tcf_meta_id(int id, unsigned char debug)
         _TCF_META_ID(DATALEN, datalen)
         _TCF_META_ID(MACLEN, maclen)
         _TCF_META_ID(NFMARK, nfmark)
+#if HAVE_DECL_TCA_TCINDEX_UNSPEC
         _TCF_META_ID(TCINDEX, tcindex)
+#endif
         _TCF_META_ID(RTCLASSID, rtclassid)
         _TCF_META_ID(RTIIF, rtiif)
         _TCF_META_ID(SK_FAMILY, sk_family)
